#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
HID0_WEBWIZARD = 34200 + 0
HID0_WEBWIZARD = 34200 + 0
HID0_HELP = 34200 + 1
HID0_NEXT = 34200 + 2
HID0_PREV = 34200 + 3
HID0_CREATE = 34200 + 4
HID0_CANCEL = 34200 + 5
HID0_STATUS_DIALOG = 34200 + 6  #step 1
HID1_LST_SESSIONS = 34200 + 7
HID1_BTN_DEL_SES = 34200 + 9    #step 2
HID2_LST_DOCS = 34200 + 10
HID2_BTN_ADD_DOC = 34200 + 11
HID2_BTN_REM_DOC = 34200 + 12
HID2_BTN_DOC_UP = 34200 + 13
HID2_BTN_DOC_DOWN = 34200 + 14
HID2_TXT_DOC_TITLE = 34200 + 15
HID2_TXT_DOC_DESC = 34200 + 16
HID2_TXT_DOC_AUTHOR = 34200 + 17
HID2_LST_DOC_EXPORT = 34200 + 18
HID2_STATUS_ADD_DOCS = 34200 + 19 #step 3
HID3_IL_LAYOUTS_IMG1 = 34200 + 20
HID3_IL_LAYOUTS_IMG2 = 34200 + 21
HID3_IL_LAYOUTS_IMG3 = 34200 + 22
HID3_IL_LAYOUTS_IMG4 = 34200 + 23
HID3_IL_LAYOUTS_IMG5 = 34200 + 24
HID3_IL_LAYOUTS_IMG6 = 34200 + 25
HID3_IL_LAYOUTS_IMG7 = 34200 + 26
HID3_IL_LAYOUTS_IMG8 = 34200 + 27
HID3_IL_LAYOUTS_IMG9 = 34200 + 28
HID3_IL_LAYOUTS_IMG10 = 34200 + 29
HID3_IL_LAYOUTS_IMG11 = 34200 + 30
HID3_IL_LAYOUTS_IMG12 = 34200 + 31
HID3_IL_LAYOUTS_IMG13 = 34200 + 32
HID3_IL_LAYOUTS_IMG14 = 34200 + 33
HID3_IL_LAYOUTS_IMG15 = 34200 + 34  #step 4
HID4_CHK_DISPLAY_FILENAME = 34200 + 35
HID4_CHK_DISPLAY_DESCRIPTION = 34200 + 36
HID4_CHK_DISPLAY_AUTHOR = 34200 + 37
HID4_CHK_DISPLAY_CR_DATE = 34200 + 38
HID4_CHK_DISPLAY_UP_DATE = 34200 + 39
HID4_CHK_DISPLAY_FORMAT = 34200 + 40
HID4_CHK_DISPLAY_F_ICON = 34200 + 41
HID4_CHK_DISPLAY_PAGES = 34200 + 42
HID4_CHK_DISPLAY_SIZE = 34200 + 43
HID4_GRP_OPTIMAIZE_640 = 34200 + 44
HID4_GRP_OPTIMAIZE_800 = 34200 + 45
HID4_GRP_OPTIMAIZE_1024 = 34200 + 46    #step 5
HID5_LST_STYLES = 34200 + 47
HID5_BTN_BACKGND = 34200 + 48
HID5_BTN_ICONS = 34200 + 49 #step 6
HID6_TXT_SITE_TITLE = 34200 + 50
HID6_TXT_SITE_ICON = 34200 + 51
HID6_BTN_SITE_ICON = 34200 + 52
HID6_TXT_SITE_DESC = 34200 + 53
HID6_TXT_SITE_KEYWRDS = 34200 + 54
HID6_DATE_SITE_CREATED = 34200 + 55
HID6_DATE_SITE_UPDATED = 34200 + 56
HID6_NUM_SITE_REVISTS = 34200 + 57
HID6_TXT_SITE_EMAIL = 34200 + 58
HID6_TXT_SITE_COPYRIGHT = 34200 + 59    #step 7
HID7_BTN_PREVIEW = 34200 + 60
HID7_CHK_PUBLISH_LOCAL = 34200 + 61
HID7_TXT_LOCAL = 34200 + 62
HID7_BTN_LOCAL = 34200 + 63
HID7_CHK_PUBLISH_ZIP = 34200 + 64
HID7_TXT_ZIP = 34200 + 65
HID7_BTN_ZIP = 34200 + 66
HID7_CHK_PUBLISH_FTP = 34200 + 67
HID7_BTN_FTP = 34200 + 69
HID7_CHK_SAVE = 34200 + 70
HID7_TXT_SAVE = 34200 + 71  #web wizard backgrounds dialog
HID_BG = 34200 + 90
HID_BG_BTN_OTHER = 34200 + 91
HID_BG_BTN_NONE = 34200 + 92
HID_BG_BTN_OK = 34200 + 93
HID_BG_BTN_CANCEL = 34200 + 94
HID_BG_BTN_BACK = 34200 + 95
HID_BG_BTN_FW = 34200 + 96
HID_BG_BTN_IMG1 = 34200 + 97
HID_BG_BTN_IMG2 = 34200 + 98
HID_BG_BTN_IMG3 = 34200 + 99
HID_BG_BTN_IMG4 = 34200 + 100
HID_BG_BTN_IMG5 = 34200 + 101
HID_BG_BTN_IMG6 = 34200 + 102
HID_BG_BTN_IMG7 = 34200 + 103
HID_BG_BTN_IMG8 = 34200 + 104
HID_BG_BTN_IMG9 = 34200 + 105
HID_BG_BTN_IMG10 = 34200 + 106
HID_BG_BTN_IMG11 = 34200 + 107
HID_BG_BTN_IMG12 = 34200 + 108  #web wizard icons sets dialog
HID_IS = 41000 + 0
HID_IS_ICONSETS = 41000 + 1
HID_IS_BTN_NONE = 41000 + 2
HID_IS_BTN_OK = 41000 + 3
HID_IS_BTN_IMG1 = 41000 + 5
HID_IS_BTN_IMG2 = 41000 + 6
HID_IS_BTN_IMG3 = 41000 + 7
HID_IS_BTN_IMG4 = 41000 + 8
HID_IS_BTN_IMG5 = 41000 + 9
HID_IS_BTN_IMG6 = 41000 + 10
HID_IS_BTN_IMG7 = 41000 + 11
HID_IS_BTN_IMG8 = 41000 + 12
HID_IS_BTN_IMG9 = 41000 + 13
HID_IS_BTN_IMG10 = 41000 + 14
HID_IS_BTN_IMG11 = 41000 + 15
HID_IS_BTN_IMG12 = 41000 + 16
HID_IS_BTN_IMG13 = 41000 + 17
HID_IS_BTN_IMG14 = 41000 + 18
HID_IS_BTN_IMG15 = 41000 + 19
HID_IS_BTN_IMG16 = 41000 + 20
HID_IS_BTN_IMG17 = 41000 + 21
HID_IS_BTN_IMG18 = 41000 + 22
HID_IS_BTN_IMG19 = 41000 + 23
HID_IS_BTN_IMG20 = 41000 + 24
HID_IS_BTN_IMG21 = 41000 + 25
HID_IS_BTN_IMG22 = 41000 + 26
HID_IS_BTN_IMG23 = 41000 + 27
HID_IS_BTN_IMG24 = 41000 + 28
HID_IS_BTN_IMG25 = 41000 + 29
HID_IS_BTN_IMG26 = 41000 + 30
HID_IS_BTN_IMG27 = 41000 + 31
HID_IS_BTN_IMG28 = 41000 + 32
HID_IS_BTN_IMG29 = 41000 + 33
HID_IS_BTN_IMG30 = 41000 + 34
HID_IS_BTN_IMG31 = 41000 + 35
HID_IS_BTN_IMG32 = 41000 + 36

#   web wizard ftp dialog
HID_FTP = 41000 + 40
HID_FTP_SERVER = 41000 + 41
HID_FTP_USERNAME = 41000 + 42
HID_FTP_PASS = 41000 + 43
HID_FTP_TEST = 41000 + 44
HID_FTP_TXT_PATH = 41000 + 45
HID_FTP_BTN_PATH = 41000 + 46
HID_FTP_OK = 41000 + 47
HID_FTP_CANCEL = 41000 + 48



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
import traceback
from ..common.PropertyNames import PropertyNames
from ..common.FileAccess import FileAccess
from ..common.SystemDialog import SystemDialog

class PathSelection(object):

    class DialogTypes(object):
        FOLDER = 0
        FILE = 1

    class TransferMode(object):
        SAVE = 0
        LOAD = 1

    def __init__(self, xMSF, CurUnoDialog, TransferMode, DialogType):
        self.CurUnoDialog = CurUnoDialog
        self.xMSF = xMSF
        self.iDialogType = DialogType
        self.iTransferMode = TransferMode
        self.sDefaultDirectory = ""
        self.sDefaultName = ""
        self.sDefaultFilter = ""
        self.usedPathPicker = False
        self.CMDSELECTPATH = 1
        self.TXTSAVEPATH = 1

    def insert(
        self, DialogStep, XPos, YPos, Width,
        CurTabIndex, LabelText, Enabled, TxtHelpURL, BtnHelpURL):

        self.CurUnoDialog.insertControlModel(
            "com.sun.star.awt.UnoControlFixedTextModel", "lblSaveAs",
            (PropertyNames.PROPERTY_ENABLED,
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (Enabled, 8, LabelText, XPos, YPos, DialogStep,
                CurTabIndex, Width))
        self.xSaveTextBox = self.CurUnoDialog.insertTextField(
            "txtSavePath", "callXPathSelectionListener",
            (PropertyNames.PROPERTY_ENABLED,
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (Enabled, 12, TxtHelpURL, XPos, YPos + 10, DialogStep,
                (CurTabIndex + 1), Width - 26), self)

        self.CurUnoDialog.xDialogModel.txtSavePath.Enabled = False
        self.CurUnoDialog.insertButton("cmdSelectPath", "triggerPathPicker",
            (PropertyNames.PROPERTY_ENABLED,
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (Enabled, 14, BtnHelpURL, "...",XPos + Width - 16, YPos + 9,
                DialogStep, (CurTabIndex + 2), 16), self)

    def addSelectionListener(self, xAction):
        self.xAction = xAction

    def getSelectedPath(self):
        return self.xSaveTextBox.Text

    def initializePath(self):
        try:
            myFA = FileAccess(self.xMSF)
            self.xSaveTextBox.setText(
                myFA.getPath(self.sDefaultDirectory + \
                    "/" + \
                    self.sDefaultName, None))
        except Exception:
            traceback.print_exc()

    def triggerPathPicker(self):
        try:
            if self.iTransferMode == self.TransferMode.SAVE:
                if self.iDialogType == self.DialogTypes.FOLDER:
                    #TODO: write code for picking a folder for saving
                    return
                elif self.iDialogType == self.DialogTypes.FILE:
                    self.usedPathPicker = True
                    myFilePickerDialog = \
                        SystemDialog.createStoreDialog(self.xMSF)
                    myFilePickerDialog.callStoreDialog(
                        self.sDefaultDirectory,
                        self.sDefaultName, self.sDefaultFilter)
                    sStorePath = myFilePickerDialog.sStorePath
                    if sStorePath is not None:
                        myFA = FileAccess(self.xMSF)
                        self.xSaveTextBox.Text = myFA.getPath(sStorePath, None)
                        self.sDefaultDirectory = \
                            FileAccess.getParentDir(sStorePath)
                        self.sDefaultName = myFA.getFilename(sStorePath)
                    return
            elif iTransferMode == TransferMode.LOAD:
                if iDialogType == DialogTypes.FOLDER:
                    #TODO: write code for picking a folder for loading
                    return
                elif iDialogType == DialogTypes.FILE:
                    #TODO: write code for picking a file for loading
                    return
        except Exception:
            traceback.print_exc()

    def callXPathSelectionListener(self):
            if self.xAction is not None:
                self.xAction.validatePath()      



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
import traceback

from .Exporter import Exporter
from ..TypeDetection import *
from ...common.Desktop import Desktop
from ...common.Properties import Properties
from ...common.FileAccess import FileAccess
from ...document.OfficeDocument import OfficeDocument
from ...text.TextDocument import TextDocument

from com.sun.star.lang import IllegalArgumentException
from com.sun.star.document.MacroExecMode import NEVER_EXECUTE
from com.sun.star.document.UpdateDocMode import NO_UPDATE

class AbstractExporter(Exporter):

    exporter = None
    fileAccess = None

    def __init__(self, exporter_):
        self.exporter = exporter_

    def storeToURL(self, officeDocument, props, targetUrl, filterName, filterData):
        props = Properties()
        props["FilterName"] = filterName
        if (len(filterData) > 0):
            props["FilterData"] = filterData
        o = props.getProperties1()
        officeDocument.storeToURL(targetUrl, tuple(o))

    def storeToURL1(self, officeDocument, targetUrl, filterName, filterData):
        self.storeToURL(officeDocument, Properties(), targetUrl, filterName, filterData)

    def storeToURL2(self, officeDocument, targetUrl, filterName):
        self.storeToURL(officeDocument, Properties(), targetUrl, filterName, [])

    def getArgument(self, name, p):
        return p.cp_Arguments.getElement(name).cp_Value

    def openDocument(self, doc, xmsf):
        document = None
        # open the document.
        try:
            desktop = Desktop.getDesktop(xmsf)
            props = list(range(3))
            props[0] = Properties.createProperty("Hidden", True)
            props[1] = Properties.createProperty("MacroExecutionMode", NEVER_EXECUTE)
            props[2] = Properties.createProperty("UpdateDocMode", NO_UPDATE)
            document = desktop.loadComponentFromURL(doc.cp_URL, "_blank", 0, tuple(props))
        except IllegalArgumentException:
            traceback.print_exc()
        # try to get the number of pages in the document
        try:
            self.pageCount(doc, document)
        except Exception:
            traceback.print_exc()
            # Here i do nothing since pages is not *so* important.
        return document

    def closeDocument(self, doc, xmsf):
        try:
            doc.close(False)
        except Exception:
            traceback.print_exc()

    def pageCount(self, doc, document):
        if (doc.appType == WRITER_DOC):
            doc.pages = TextDocument.getPageCount(document)
        elif (doc.appType == IMPRESS_DOC):
            doc.pages = OfficeDocument.getSlideCount(document)
        elif (doc.appType == DRAW_DOC):
            doc.pages = OfficeDocument.getSlideCount(document)

    def getFileAccess(self, xmsf):
        if (self.fileAccess == None):
            try:
                self.fileAccess = FileAccess(xmsf)
            except Exception:
                traceback.print_exc()
        return self.fileAccess

    def calcFileSize(self, doc, url, xmsf):
        # if the exporter exports to a
        # binary format, get the size of the destination.
        if (self.exporter.cp_Binary):
            doc.sizeBytes = self.getFileAccess(xmsf).getSize(url)



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
import traceback

from .TaskEvent import TaskEvent

class Task:
    successful = 0
    failed = 0
    maximum = 0
    taskName = ""
    listeners = []
    subtaskName = ""

    def __init__(self, taskName_, subtaskName_, max_):
        self.taskName = taskName_
        self.subtaskName = subtaskName_
        self.maximum = max_

    def start(self):
        self.fireTaskStarted()

    def fail(self):
        self.fireTaskFailed()

    def getMax(self):
        return self.maximum

    def setMax(self, max_):
        self.maximum = max_
        self.fireTaskStatusChanged()

    def advance(self, success_):
        if success_:
            self.successful += 1
            print ("Success :", self.successful)
        else:
            self.failed += 1
            print ("Failed :", self.failed)
        self.fireTaskStatusChanged()
        if (self.failed + self.successful == self.maximum):
            self.fireTaskFinished()

    def advance1(self, success_, nextSubtaskName):
        self.advance(success_)
        self.setSubtaskName(nextSubtaskName)

    def getStatus(self):
        return self.successful + self.failed

    def addTaskListener(self, tl):
        self.listeners.append(tl)

    def removeTaskListener(self, tl):
        try:
            index = self.listeners.index(tl)
            self.listeners.pop(index)
        except Exception:
            traceback.print_exc()

    def fireTaskStatusChanged(self):
        te = TaskEvent(self, TaskEvent.TASK_STATUS_CHANGED)
        for i in range(len(self.listeners)):
            self.listeners[i].taskStatusChanged(te)

    def fireTaskStarted(self):
        te = TaskEvent(self, TaskEvent.TASK_STARTED)
        for i in range(len(self.listeners)):
            self.listeners[i].taskStarted(te)

    def fireTaskFailed(self):
        te = TaskEvent(self, TaskEvent.TASK_FAILED)
        for i in range(len(self.listeners)):
            self.listeners[i].taskFinished(te)

    def fireTaskFinished(self):
        te = TaskEvent(self, TaskEvent.TASK_FINISHED)
        for i in range(len(self.listeners)):
            self.listeners[i].taskFinished(te)

    def fireSubtaskNameChanged(self):
        te = TaskEvent(self, TaskEvent.SUBTASK_NAME_CHANGED)
        for i in range(len(self.listeners)):
            self.listeners[i].subtaskNameChanged(te)

    def getSubtaskName(self):
        return self.subtaskName

    def getTaskName(self):
        return self.taskName

    def setSubtaskName(self, s):
        self.subtaskName = s
        self.fireSubtaskNameChanged()

    def getFailed(self):
        return self.failed

    def getSuccessfull(self):
        return self.successful



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
import traceback
#import uno before importing from VclWindowPeerAttribute
import uno
from com.sun.star.awt.VclWindowPeerAttribute import OK

class Resource(object):

    def __init__(self, _xMSF, _Module):
        self.xMSF = _xMSF
        self.Module = _Module
        try:
            xResource = self.xMSF.createInstanceWithArguments(
                "org.libreoffice.resource.ResourceIndexAccess", (self.Module,))
            if xResource is None:
                raise Exception ("could not initialize ResourceIndexAccess")

            self.xStringIndexAccess = xResource.getByName("String")

            if self.xStringIndexAccess is None:
                raise Exception ("could not initialize xStringIndexAccess")

        except Exception:
            traceback.print_exc()
            self.showCommonResourceError(self.xMSF)

    def getResText(self, nID):
        try:
            return self.xStringIndexAccess.getByIndex(nID)
        except Exception:
            traceback.print_exc()
            raise ValueError("Resource with ID not " + str(nID) + " not found")

    def getResArray(self, nID, iCount):
        try:
            resArray = []
            for i in range(iCount):
                resArray.append(self.getResText(nID + i))
            return resArray
        except Exception:
            traceback.print_exc()
            raise ValueError("Resource with ID not" + str(nID) + " not found")

    @classmethod
    def showCommonResourceError(self, xMSF):
        from .SystemDialog import SystemDialog
        sError = "The files required could not be found.\n" + \
            "Please start the LibreOffice Setup and choose 'Repair'."
        SystemDialog.showMessageBox(xMSF, "ErrorBox", OK, sError)



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
from ..ui.WizardDialog import WizardDialog, uno, PropertyNames
from .WebWizardDialogResources import WebWizardDialogResources
from .WebWizardConst import *
from .WWHID import *
from ..ui.ControlScroller import HelpIds
from ..ui.ImageList import ImageList
from com.sun.star.awt import Size
from com.sun.star.awt.FontUnderline import SINGLE
from com.sun.star.awt.FontFamily import ROMAN
from com.sun.star.awt.FontSlant import ITALIC
from com.sun.star.awt.ImageAlign import LEFT

class WebWizardDialog(WizardDialog):
    PROPNAMES_LBL = (PropertyNames.PROPERTY_HEIGHT,
        PropertyNames.PROPERTY_LABEL,
        PropertyNames.PROPERTY_NAME,
        PropertyNames.PROPERTY_POSITION_X,
        PropertyNames.PROPERTY_POSITION_Y,
        PropertyNames.PROPERTY_STEP,
        PropertyNames.PROPERTY_TABINDEX,
        PropertyNames.PROPERTY_WIDTH)
    PROPNAMES_CHKBOX = (PropertyNames.PROPERTY_HEIGHT,
        PropertyNames.PROPERTY_HELPURL,
        PropertyNames.PROPERTY_LABEL,
        PropertyNames.PROPERTY_NAME,
        PropertyNames.PROPERTY_POSITION_X,
        PropertyNames.PROPERTY_POSITION_Y,
        PropertyNames.PROPERTY_STATE,
        PropertyNames.PROPERTY_STEP,
        PropertyNames.PROPERTY_TABINDEX,
        PropertyNames.PROPERTY_WIDTH)
    PROPNAMES_BUTTON = (PropertyNames.PROPERTY_HEIGHT,
        PropertyNames.PROPERTY_HELPURL,
        PropertyNames.PROPERTY_LABEL,
        PropertyNames.PROPERTY_NAME,
        PropertyNames.PROPERTY_POSITION_X,
        PropertyNames.PROPERTY_POSITION_Y,
        PropertyNames.PROPERTY_STEP,
        PropertyNames.PROPERTY_TABINDEX,
        PropertyNames.PROPERTY_WIDTH)
    PROPNAMES_TXT = (PropertyNames.PROPERTY_HEIGHT,
        PropertyNames.PROPERTY_HELPURL,
        PropertyNames.PROPERTY_NAME,
        PropertyNames.PROPERTY_POSITION_X,
        PropertyNames.PROPERTY_POSITION_Y,
        PropertyNames.PROPERTY_STEP,
        PropertyNames.PROPERTY_TABINDEX,
        PropertyNames.PROPERTY_WIDTH)
    PROPNAMES_TXT_2 = (PropertyNames.PROPERTY_HEIGHT,
        PropertyNames.PROPERTY_HELPURL,
        PropertyNames.PROPERTY_NAME,
        PropertyNames.PROPERTY_POSITION_X,
        PropertyNames.PROPERTY_POSITION_Y, "ReadOnly",
        PropertyNames.PROPERTY_STEP,
        PropertyNames.PROPERTY_TABINDEX,
        PropertyNames.PROPERTY_WIDTH)
    PROPNAMES_TITLE = ("FontDescriptor",
        PropertyNames.PROPERTY_HEIGHT,
        PropertyNames.PROPERTY_LABEL,
        PropertyNames.PROPERTY_MULTILINE,
        PropertyNames.PROPERTY_NAME,
        PropertyNames.PROPERTY_POSITION_X,
        PropertyNames.PROPERTY_POSITION_Y,
        PropertyNames.PROPERTY_STEP,
        PropertyNames.PROPERTY_TABINDEX,
        PropertyNames.PROPERTY_WIDTH)

    def __init__(self, xmsf):
        super(WebWizardDialog, self).__init__(xmsf, HID0_WEBWIZARD)
        
        #Load Resources
        self.resources = WebWizardDialogResources(xmsf, self.oWizardResource)
        
        #set dialog properties...
        self.setDialogProperties( True, 210, True, 102, 52, 1, 6, 
            self.resources.resWebWizardDialog_title, 330)
            
        self.fontDescriptor4 = \
            uno.createUnoStruct('com.sun.star.awt.FontDescriptor')
        self.fontDescriptor5 = \
            uno.createUnoStruct('com.sun.star.awt.FontDescriptor')
        self.fontDescriptor6 = \
            uno.createUnoStruct('com.sun.star.awt.FontDescriptor')
        self.fontDescriptor7 = \
            uno.createUnoStruct('com.sun.star.awt.FontDescriptor')
            
        self.fontDescriptor4.Weight = 150
        self.fontDescriptor5.Name = "Angsana New"
        self.fontDescriptor5.Height = 16
        self.fontDescriptor5.StyleName = "Regular"
        self.fontDescriptor5.Family = ROMAN
        self.fontDescriptor5.Weight = 100
        self.fontDescriptor6.Name = "Andalus"
        self.fontDescriptor6.Height = 22
        self.fontDescriptor6.StyleName = "Bold Italic"
        self.fontDescriptor6.Weight = 150
        self.fontDescriptor6.Slant = ITALIC
        self.fontDescriptor7.Name = "OpenSymbol"
        self.fontDescriptor7.Height = 9
        self.fontDescriptor7.StyleName = "Regular"
        self.fontDescriptor7.Weight = 100

    def buildStep1(self):
        tabIndex = 100
        self.insertLabel("lbIntroTitle", WebWizardDialog.PROPNAMES_TITLE,
            (self.fontDescriptor4, 16, self.resources.reslbIntroTitle_value,
                True, "lbIntroTitle", 91, 8, 1, tabIndex + 1, 232))
        self.insertLabel("lblIntroduction",
            (PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_MULTILINE,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (119, self.resources.reslblIntroduction_value, True,
                "lblIntroduction", 97, 28, 1, tabIndex + 1, 226))
        self.insertFixedLine("lnLoadSettings", WebWizardDialog.PROPNAMES_TXT,
            (2, "", "lnLoadSettings", 91, 147, 1, tabIndex + 1, 234))
        self.lblLoadSettings = self.insertLabel("lblLoadSettings",
            (PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_MULTILINE,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (8, self.resources.reslblLoadSettings_value, True,
                "lblLoadSettings", 97, 153, 1, tabIndex + 1, 226))
        self.lstLoadSettings = self.insertListBox(
            "lstLoadSettings", None, LSTLOADSETTINGS_ITEM_CHANGED,("Dropdown",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL, "LineCount",
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (True, 12, HelpIds.getHelpIdString(HID1_LST_SESSIONS), 14,
                "lstLoadSettings", 97, 165, 1, tabIndex + 1, 173), self)
        self.btnDelSession = self.insertButton(
            "btnDelSession", BTNDELSESSION_ACTION_PERFORMED,
            (PropertyNames.PROPERTY_ENABLED,
                    PropertyNames.PROPERTY_HEIGHT,
                    PropertyNames.PROPERTY_HELPURL, "ImageAlign",
                    PropertyNames.PROPERTY_LABEL,
                    PropertyNames.PROPERTY_NAME,
                    PropertyNames.PROPERTY_POSITION_X,
                    PropertyNames.PROPERTY_POSITION_Y,
                    PropertyNames.PROPERTY_STEP,
                    PropertyNames.PROPERTY_TABINDEX,
                    PropertyNames.PROPERTY_WIDTH),
            (False, 14, HelpIds.getHelpIdString(HID1_BTN_DEL_SES), LEFT,
                self.resources.resbtnDelSession_value, "btnDelSession",
                274, 164, 1, tabIndex + 1, 50), self)

    def buildStep2(self):
        tabIndex = 200
        self.lblContentTitle = self.insertLabel(
            "lblContentTitle", WebWizardDialog.PROPNAMES_TITLE,
            (self.fontDescriptor4, 16, self.resources.reslblContentTitle_value,
                True, "lblContentTitle", 91, 8, 2, tabIndex + 1, 232))
        self.lblSiteContent = self.insertLabel(
            "lblSiteContent", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblSiteContent_value,
                "lblSiteContent", 97, 28, 2, tabIndex + 1, 105))
        self.lstDocuments = self.insertListBox(
            "lstDocuments", None, None,
            (PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                "LineCount",
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (123, HelpIds.getHelpIdString(HID2_LST_DOCS),
                9, "lstDocuments", 97, 38, 2, tabIndex + 1, 103), self)
        self.btnAddDoc = self.insertButton(
            "btnAddDoc", BTNADDDOC_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID2_BTN_ADD_DOC),
            self.resources.resbtnAddDoc_value, "btnAddDoc", 97, 165, 2,
                tabIndex + 1, 50), self)
        self.btnRemoveDoc = self.insertButton(
            "btnRemoveDoc", BTNREMOVEDOC_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID2_BTN_REM_DOC),
                self.resources.resbtnRemoveDoc_value, "btnRemoveDoc", 150, 165,
                2, tabIndex + 1, 50), self)
        self.btnDocUp = self.insertButton(
            "btnDocUp", BTNDOCUP_ACTION_PERFORMED,
            ("FontDescriptor",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (self.fontDescriptor7, 14, HelpIds.getHelpIdString(HID2_BTN_DOC_UP),
                self.resources.resbtnDocUp_value, "btnDocUp",
                205, 87, 2, tabIndex + 1, 18), self)
        self.btnDocDown = self.insertButton(
            "btnDocDown", BTNDOCDOWN_ACTION_PERFORMED,(
                "FontDescriptor",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (self.fontDescriptor7, 14, HelpIds.getHelpIdString(HID2_BTN_DOC_DOWN),
                self.resources.resbtnDocDown_value, "btnDocDown", 205,
                105, 2, tabIndex + 1, 18), self)
        self.lblDocExportFormat = self.insertLabel(
            "lblDocExportFormat", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblDocExportFormat_value,
                "lblDocExportFormat", 235, 28, 2, tabIndex + 1, 89))
        self.lstDocTargetType = self.insertListBox("lstDocTargetType", None, None,
            ("Dropdown",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL, "LineCount",
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (True, 12, HelpIds.getHelpIdString(HID2_LST_DOC_EXPORT), 14,
                "lstDocTargetType", 235, 38, 2, tabIndex + 1, 89), self)
        self.lnDocsInfo = self.insertFixedLine(
            "lnDocsInfo", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslnDocsInfo_value, "lnDocsInfo",
                235, 66, 2, tabIndex + 1, 90))
        self.lblDocTitle = self.insertLabel(
            "lblDocTitle", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblDocTitle_value, "lblDocTitle",
                235, 78, 2, tabIndex + 1, 89))
        self.txtDocTitle = self.insertTextField(
            "txtDocTitle", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID2_TXT_DOC_TITLE), "txtDocTitle",
                235, 88, 2, tabIndex + 1, 89), self)
        self.lblDocInfo = self.insertLabel(
            "lblDocInfo", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblDocInfo_value, "lblDocInfo",
                235, 103, 2, tabIndex + 1, 89))
        self.txtDocInfo = self.insertTextField(
            "txtDocInfo", None,(PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                PropertyNames.PROPERTY_MULTILINE,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (40, HelpIds.getHelpIdString(HID2_TXT_DOC_DESC), True,
                "txtDocInfo", 235, 113, 2, tabIndex + 1, 89), self)
        self.lblDocAuthor = self.insertLabel(
            "lblDocAuthor", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblDocAuthor_value, "lblDocAuthor",
                235, 155, 2, tabIndex + 1, 89))
        self.txtDocAuthor = self.insertTextField(
            "txtDocAuthor", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID2_TXT_DOC_AUTHOR),
                "txtDocAuthor", 235, 165, 2, tabIndex + 1, 89), self)

    def buildStep3(self):
        self.insertLabel("lblLayoutTitle", WebWizardDialog.PROPNAMES_TITLE,
            (self.fontDescriptor4, 16, self.resources.reslblLayoutTitle_value,
                True, "lblLayoutTitle", 91, 8, 3, 29, 232))
        self.lblLayouts = self.insertLabel("lblLayouts",
            WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblLayouts_value, "lblLayouts",
                97, 28, 3, 30, 206))

    def buildStep4(self):
        self.insertLabel("lblLayout2Title", WebWizardDialog.PROPNAMES_TITLE,
            (self.fontDescriptor4, 16, self.resources.reslblLayout2Title_value,
                True, "lblLayout2Title", 91, 8, 4, 33, 232))
        self.lnDisplay = self.insertLabel("lblDisplay",
            (PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_MULTILINE,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (16, self.resources.reslblDisplay_value, True,
                "lblDisplay", 97, 28, 4, 34, 226))
        self.chkDocFilename = self.insertCheckBox("chkDocFilename", None,
            WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_FILENAME),
                self.resources.reschkDocFilename_value, "chkDocFilename",
                103, 50, 0, 4, 35, 99), self)
        self.chbDocDesc = self.insertCheckBox(
            "chbDocDesc", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_DESCRIPTION),
                self.resources.reschbDocDesc_value, "chbDocDesc",
                103, 60, 0, 4, 36, 99), self)
        self.chbDocAuthor = self.insertCheckBox(
            "chbDocAuthor", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_AUTHOR),
                self.resources.reschbDocAuthor_value, "chbDocAuthor",
                103, 70, 0, 4, 37, 99), self)
        self.chkDocCreated = self.insertCheckBox(
            "chkDocCreated", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_CR_DATE),
                self.resources.reschkDocCreated_value, "chkDocCreated",
                103, 80, 0, 4, 38, 99), self)
        self.chkDocChanged = self.insertCheckBox(
            "chkDocChanged", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_UP_DATE),
                self.resources.reschkDocChanged_value, "chkDocChanged",
                103, 90, 0, 4, 39, 99), self)
        self.chkDocFormat = self.insertCheckBox(
            "chkDocFormat", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_FORMAT),
                self.resources.reschkDocFormat_value, "chkDocFormat",
                200, 50, 0, 4, 40, 110), self)
        self.chkDocFormatIcon = self.insertCheckBox(
            "chkDocFormatIcon", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_F_ICON),
                self.resources.reschkDocFormatIcon_value, "chkDocFormatIcon",
                200, 60, 0, 4, 41, 110), self)
        self.chkDocPages = self.insertCheckBox(
            "chkDocPages", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_PAGES),
                self.resources.reschkDocPages_value, "chkDocPages",
                200,70, 0, 4, 42, 110), self)
        self.chkDocSize = self.insertCheckBox(
            "chkDocSize", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID4_CHK_DISPLAY_SIZE),
                self.resources.reschkDocSize_value, "chkDocSize",
                200, 80, 0, 4, 43, 110), self)
        self.insertLabel("lblOptimizeFor", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblOptimizeFor_value, "lblOptimizeFor",
                97, 113, 4, 44, 226))
        self.optOptimize640x480 = self.insertRadioButton(
            "optOptimize640x480", None, WebWizardDialog.PROPNAMES_BUTTON,
            (10, HelpIds.getHelpIdString(HID4_GRP_OPTIMAIZE_640),
                self.resources.resoptOptimize640x480_value,
                    "optOptimize640x480", 103, 133, 4, 45, 44), self)
        self.optOptimize800x600 = self.insertRadioButton(
            "optOptimize800x600", None, WebWizardDialog.PROPNAMES_BUTTON,
            (10, HelpIds.getHelpIdString(HID4_GRP_OPTIMAIZE_800),
                self.resources.resoptOptimize800x600_value,
                "optOptimize800x600", 103, 146, 4, 46, 44), self)
        self.optOptimize1024x768 = self.insertRadioButton(
            "optOptimize1024x768", None, WebWizardDialog.PROPNAMES_BUTTON,
            (10, HelpIds.getHelpIdString(HID4_GRP_OPTIMAIZE_1024),
                self.resources.resoptOptimize1024x768_value,
                "optOptimize1024x768", 103, 158, 4, 47, 44), self)

    def buildStep5(self):
        self.lblStyleTitle = self.insertLabel(
            "lblStyleTitle", WebWizardDialog.PROPNAMES_TITLE,
            (self.fontDescriptor4, 16, self.resources.reslblStyleTitle_value,
                True, "lblStyleTitle", 91, 8, 5, 50, 232))
        self.lblStyle = self.insertLabel(
            "lblStyle", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblStyle_value,
                "lblStyle", 97, 28, 5, 51, 80))
        self.lstStyles = self.insertListBox(
            "lstStyles", None, LSTSTYLES_ITEM_CHANGED,(
                "Dropdown",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL, "LineCount",
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (True, 12, HelpIds.getHelpIdString(HID5_LST_STYLES),
                14, "lstStyles", 179, 26, 5, 52, 145), self)
        self.insertLabel("lblBackground", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblBackground, "lblBackground",
                97, 46, 5, 51, 70))
        self.txtBackground = self.insertLabel("txtBackground",
            ("Border",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (1, 12, self.resources.resBackgroundNone,
                "txtBackground", 179, 44, 5, 52, 90))
        self.btnBackgrounds = self.insertButton(
            "btnBackgrounds", BTNBACKGROUNDS_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID5_BTN_BACKGND),
                self.resources.resBtnChooseBackground, "btnBackgrounds",
                274, 43, 5, 53, 50), self)
        self.insertLabel("lblIconset", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblIconset, "lblIconset", 97, 64, 5, 51, 70))
        self.txtIconset = self.insertLabel("txtIconset",
            ("Border",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (1, 12, self.resources.resIconsetNone, "txtIconset",
                179, 62, 5, 52, 90))
        self.btnIconSets = self.insertButton(
            "btnIconSets", BTNICONSETS_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID5_BTN_ICONS),
                self.resources.resBtnChooseIconset, "btnIconSets",
                274, 61, 5, 54, 50), self)
        self.insertLabel("lblIconsetInfo",
            (PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_LABEL,
                PropertyNames.PROPERTY_MULTILINE,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (16, self.resources.reslblIconSetInfo, True, "lblIconsetInfo",
                179, 78, 5, 51, 145))
        self.imgPreview = self.insertImage("imgPreview",
            ("BackgroundColor",
                PropertyNames.PROPERTY_ENABLED,
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_IMAGEURL,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y, "ScaleImage",
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (0, False, 78, "", "imgPreview", 91, 100, False, 5, 55, 232))

    def buildStep6(self):
        tabIndex = 60
        self.insertLabel("lblTitleGeneralPage",
            WebWizardDialog.PROPNAMES_TITLE,
            (self.fontDescriptor4, 8,
                self.resources.reslblTitleGeneralPage_value, True,
                "lblTitleGeneralPage", 90, 9, 6, tabIndex + 1, 232))
        self.insertLabel("lblSiteTitle", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblSiteTitle_value, "lblSiteTitle",
                97, 28, 6, tabIndex + 1, 80))
        self.txtSiteTitle = self.insertTextField(
            "txtSiteTitle", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID6_TXT_SITE_TITLE),
                "txtSiteTitle", 179, 26, 6, tabIndex + 1, 145), self)
        self.insertFixedLine(
            "FixedLineMetaData", WebWizardDialog.PROPNAMES_LBL,
            (9, self.resources.reslblMetaData, "FixedLineMetaData",
                97, 56, 6, tabIndex + 1, 228))
        self.insertLabel("lblSiteDesc", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblSiteDesc_value, "lblSiteDesc",
                103, 72, 6, tabIndex + 1, 80))
        self.txtSiteDesc = self.insertTextField(
            "txtSiteDesc", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID6_TXT_SITE_DESC), "txtSiteDesc",
                179, 70, 6, tabIndex + 1, 145), self)
        self.insertLabel(
            "lblEmail", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblEmail_value, "lblEmail",
                103, 90, 6, tabIndex + 1, 80))
        self.txtEmail = self.insertTextField(
            "txtEmail", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID6_TXT_SITE_EMAIL), "txtEmail",
                179, 87, 6, tabIndex + 1, 145), self)
        self.insertLabel("lblCopyright", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblCopyright_value, "lblCopyright",
                103, 108, 6, tabIndex + 1, 80))
        self.txtCopyright = self.insertTextField(
            "txtCopyright", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID6_TXT_SITE_COPYRIGHT),
                "txtCopyright", 179, 106, 6, tabIndex + 1, 145), self)
        self.insertLabel("lblSiteCreated", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblSiteCreated_value, "lblSiteCreated",
                103, 126, 6, tabIndex + 1, 80))
        self.dateSiteCreated = self.insertDateField("dateSiteCreated", None,
            ("Dropdown",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (True, 12, HelpIds.getHelpIdString(HID6_DATE_SITE_CREATED),
                "dateSiteCreated", 179, 124, 6, tabIndex + 1, 49), self)
        self.insertLabel("lblSiteUpdated", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblSiteUpdated_value, "lblSiteUpdated",
                103, 144, 6, tabIndex + 1, 80))
        self.dateSiteUpdate = self.insertDateField("dateSiteUpdate", None,
            ("Dropdown",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (True, 12, HelpIds.getHelpIdString(HID6_DATE_SITE_UPDATED),
                "dateSiteUpdate", 179, 142, 6, tabIndex + 1, 49), self)

    def buildStep7(self, disableFTP, exclamationURL):
        tabIndex = 700
        self.lblTitlePublish = self.insertLabel(
            "lblTitlePublish", WebWizardDialog.PROPNAMES_TITLE,
            (self.fontDescriptor4, 16, self.resources.reslblTitlePublish_value,
                True, "lblTitlePublish", 91, 8, 7, tabIndex + 1, 232))
        self.FixedLine1 = self.insertFixedLine(
            "FixedLine1", WebWizardDialog.PROPNAMES_LBL,
            (9, self.resources.resFixedLine1_value, "FixedLine1",
                97, 28, 7, tabIndex + 1, 228))
        self.btnPreview = self.insertButton(
            "btnPreview", BTNPREVIEW_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID7_BTN_PREVIEW),
                self.resources.resbtnPreview_value, "btnPreview",
                    103, 40, 7, tabIndex + 1, 50), self)
        self.insertFixedLine(
            "lblCreateSite", WebWizardDialog.PROPNAMES_LBL,
            (9, self.resources.reslblCreateSite_value, "lblCreateSite",
                97, 56, 7, tabIndex + 1, 228))
        self.chkLocalDir = self.insertCheckBox(
            "chkLocalDir", CHKLOCALDIR_ITEM_CHANGED,
            WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID7_CHK_PUBLISH_LOCAL),
                self.resources.reschkLocalDir_value, "chkLocalDir",
                103, 68, 0, 7, tabIndex + 1, 215), self)
        self.txtLocalDir = self.insertTextField(
            "txtLocalDir", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID7_TXT_LOCAL), "txtLocalDir",
                113, 78, 7, tabIndex + 1, 190), self)
        self.btnLocalDir = self.insertButton(
            "btnLocalDir", BTNLOCALDIR_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID7_BTN_LOCAL),
                self.resources.resbtnLocalDir_value, "btnLocalDir",
                308, 77, 7, tabIndex + 1, 16), self)
        self.chkZip = self.insertCheckBox(
            "chkZip", CHKZIP_ITEM_CHANGED, 
            WebWizardDialog.PROPNAMES_CHKBOX,
            (9, HelpIds.getHelpIdString(HID7_CHK_PUBLISH_ZIP),
                self.resources.reschkZip_value, "chkZip", 103, 96, 0, 7,
                tabIndex + 1, 215), self)
        self.txtZip = self.insertTextField(
            "txtZip", None, WebWizardDialog.PROPNAMES_TXT,
            (12, HelpIds.getHelpIdString(HID7_TXT_ZIP), "txtZip",
                113, 108, 7, tabIndex + 1, 190), self)
        self.btnZip = self.insertButton(
            "btnZip", BTNZIP_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID7_BTN_ZIP),
                self.resources.resbtnZip_value, "btnZip", 308, 107, 7,
                tabIndex + 1, 16), self)
        self.chkFTP = self.insertCheckBox(
            "chkFTP", None, WebWizardDialog.PROPNAMES_CHKBOX,
            (8, HelpIds.getHelpIdString(HID7_CHK_PUBLISH_FTP),
                self.resources.reschkFTP_value, "chkFTP", 103, 124, 0, 7,
                tabIndex + 1, 215), self)
        if disableFTP:
            FTP_STEP = 99
        else:
            FTP_STEP = 7

        self.lblFTP = self.insertLabel(
            "lblFTP", ("Border",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (1, 12, "txtFTP", 113, 134, FTP_STEP, tabIndex + 1, 156))
        self.btnFTP = self.insertButton(
            "btnFTP", BTNFTP_ACTION_PERFORMED,
            WebWizardDialog.PROPNAMES_BUTTON,
            (14, HelpIds.getHelpIdString(HID7_BTN_FTP),
                self.resources.resbtnFTP_value, "btnFTP", 274, 133,
                FTP_STEP, tabIndex + 1, 50), self)
        if disableFTP:
            self.insertImage(
                "imgFTPDisabled",("BackgroundColor", "Border",
                    PropertyNames.PROPERTY_ENABLED,
                    PropertyNames.PROPERTY_HEIGHT,
                    PropertyNames.PROPERTY_IMAGEURL,
                    PropertyNames.PROPERTY_NAME,
                    PropertyNames.PROPERTY_POSITION_X,
                    PropertyNames.PROPERTY_POSITION_Y, "ScaleImage",
                    PropertyNames.PROPERTY_STEP,
                    PropertyNames.PROPERTY_TABINDEX,
                    PropertyNames.PROPERTY_WIDTH),
                (-1, 0, False, 10, exclamationURL, "imgFTPDisabled", 115,
                    135, False, 7, tabIndex + 1, 8))
            self.insertLabel(
                "lblFTPDisabled",("BackgroundColor",
                    PropertyNames.PROPERTY_HEIGHT,
                    PropertyNames.PROPERTY_LABEL,
                    PropertyNames.PROPERTY_MULTILINE,
                    PropertyNames.PROPERTY_NAME,
                    PropertyNames.PROPERTY_POSITION_X,
                    PropertyNames.PROPERTY_POSITION_Y,
                    PropertyNames.PROPERTY_STEP,
                    PropertyNames.PROPERTY_TABINDEX,
                    PropertyNames.PROPERTY_WIDTH),
                (-1, 8, self.resources.reslblFTPDisabled, True,
                    "lblFTPDisabled", 125, 136, 7, tabIndex + 1, 226))

        self.insertFixedLine(
            "lnSaveSetting", WebWizardDialog.PROPNAMES_TXT,
            (2, "", "lnSaveSetting", 97, 151, 7, tabIndex + 1, 228))
        self.chkSaveSettings = self.insertCheckBox(
            "chkSaveSettings", CHKSAVESETTINGS_ITEM_CHANGED,
            WebWizardDialog.PROPNAMES_CHKBOX,
            (9, HelpIds.getHelpIdString(HID7_CHK_SAVE),
                self.resources.reschkSaveSettings_value, "chkSaveSettings",
                97, 157, 1, 7, tabIndex + 1, 215), self)
        self.insertLabel(
            "lblSaveSettings", WebWizardDialog.PROPNAMES_LBL,
            (8, self.resources.reslblSaveSettings_value, "lblSaveSettings",
                107, 169, 7, tabIndex + 1, 45))
        self.cbSaveSettings = self.insertComboBox(
            "txtSaveSettings", TXTSAVESETTINGS_TEXT_CHANGED,
            TXTSAVESETTINGS_TEXT_CHANGED, TXTSAVESETTINGS_TEXT_CHANGED,
            ("Autocomplete", "Dropdown",
                PropertyNames.PROPERTY_HEIGHT,
                PropertyNames.PROPERTY_HELPURL, "LineCount",
                PropertyNames.PROPERTY_NAME,
                PropertyNames.PROPERTY_POSITION_X,
                PropertyNames.PROPERTY_POSITION_Y,
                PropertyNames.PROPERTY_STEP,
                PropertyNames.PROPERTY_TABINDEX,
                PropertyNames.PROPERTY_WIDTH),
            (True, True, 12, HelpIds.getHelpIdString(HID7_TXT_SAVE),
                14, "txtSaveSettings", 179, 167, 7, tabIndex + 1, 145), self)

    '''
    builds the layouts image list.
    '''

    def buildStepX(self):
        self.ilLayouts = ImageList()
        self.ilLayouts.pos = Size (97, 38)
        self.ilLayouts.imageSize = Size (34, 30)
        self.ilLayouts.cols = 5
        self.ilLayouts.rows = 3
        self.ilLayouts.step = 3
        self.ilLayouts.showButtons = False
        self.ilLayouts.renderer = self.LayoutRenderer()
        self.ilLayouts.scaleImages = False
        self.ilLayouts.tabIndex = 31
        self.ilLayouts.helpURL = HID3_IL_LAYOUTS_IMG1


    '''
    renders the images and titles of
    the layouts
    @author rpiterman
    '''

    class LayoutRenderer:

        def getImageUrls(self, listItem):
            oResIds = None
            if listItem is not None:
                oResIds = listItem.getImageUrls()

            return oResIds

        def render(self, listItem):
            return "" if (listItem is None) else listItem.cp_Name



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
from ..text.TextDocument import TextDocument, traceback, \
    TextFieldHandler, Configuration
from ..text.TextSectionHandler import TextSectionHandler

from com.sun.star.table import BorderLine
from com.sun.star.text.ControlCharacter import PARAGRAPH_BREAK
from com.sun.star.style.ParagraphAdjust import CENTER
from com.sun.star.text.PageNumberType import CURRENT
from com.sun.star.style.NumberingType import ARABIC
from com.sun.star.text.HoriOrientation import NONE as NONEHORI
from com.sun.star.text.VertOrientation import NONE as NONEVERT
from com.sun.star.text.RelOrientation import PAGE_FRAME
from com.sun.star.text.TextContentAnchorType import AT_PAGE
from com.sun.star.text.SizeType import FIX
from com.sun.star.text.WrapTextMode import THROUGHT
from com.sun.star.awt.FontWeight import BOLD
from com.sun.star.beans import UnknownPropertyException

class LetterDocument(TextDocument):

    def __init__(self, xMSF, listener):
        super(LetterDocument,self).__init__(xMSF, listener, None,
            "WIZARD_LIVE_PREVIEW")
        self.keepLogoFrame = True
        self.keepBendMarksFrame = True
        self.keepLetterSignsFrame = True
        self.keepSenderAddressRepeatedFrame = True
        self.keepAddressFrame = True

    def switchElement(self, sElement, bState):
        try:
            mySectionHandler = TextSectionHandler(
                self.xMSF, self.xTextDocument)
            oSection = \
                mySectionHandler.xTextDocument.TextSections.getByName(sElement)
            oSection.IsVisible = bState
        except Exception:
            traceback.print_exc()

    def updateDateFields(self):
        FH = TextFieldHandler(
            self.xTextDocument, self.xTextDocument)
        FH.updateDateFields()

    def switchFooter(self, sPageStyle, bState, bPageNumber, sText):
        if self.xTextDocument is not None:
            try:
                self.xTextDocument.lockControllers()
                xNameAccess = self.xTextDocument.StyleFamilies
                xPageStyleCollection = xNameAccess.getByName("PageStyles")
                xPageStyle = xPageStyleCollection.getByName(sPageStyle)
                if bState:
                    xPageStyle.FooterIsOn = True
                    xFooterText = xPageStyle.FooterText
                    xFooterText.String = sText
                    if bPageNumber:
                        #Adding the Page Number
                        myCursor = xFooterText.Text.createTextCursor()
                        myCursor.gotoEnd(False)
                        xFooterText.insertControlCharacter(myCursor,
                            PARAGRAPH_BREAK, False)
                        myCursor.setPropertyValue("ParaAdjust", CENTER )

                        xPageNumberField = \
                            self.xTextDocument.createInstance(
                                "com.sun.star.text.TextField.PageNumber")
                        xPageNumberField.setPropertyValue("SubType", CURRENT)
                        xPageNumberField.NumberingType = ARABIC
                        xFooterText.insertTextContent(xFooterText.End,
                            xPageNumberField, False)

                else:
                    xPageStyle.FooterIsOn = False

                self.xTextDocument.unlockControllers()
            except Exception:
                traceback.print_exc()

    def hasElement(self, sElement):
        if self.xTextDocument is not None:
            SH = TextSectionHandler(self.xMSF, self.xTextDocument)
            return SH.hasTextSectionByName(sElement)
        else:
            return False

    def switchUserField(self, sFieldName, sNewContent, bState):
        myFieldHandler = TextFieldHandler(
            self.xMSF, self.xTextDocument)
        if bState:
            myFieldHandler.changeUserFieldContent(sFieldName, sNewContent)
        else:
            myFieldHandler.changeUserFieldContent(sFieldName, "")

    def fillSenderWithUserData(self):
        try:
            myFieldHandler = TextFieldHandler(
                self.xTextDocument, self.xTextDocument)
            oUserDataAccess = Configuration.getConfigurationRoot(
                self.xMSF, "org.openoffice.UserProfile/Data", False)
            myFieldHandler.changeUserFieldContent(
                "Company", oUserDataAccess.getByName("o"))
            myFieldHandler.changeUserFieldContent(
                "Street", oUserDataAccess.getByName("street"))
            myFieldHandler.changeUserFieldContent(
                "PostCode", oUserDataAccess.getByName("postalcode"))
            myFieldHandler.changeUserFieldContent(
                "City", oUserDataAccess.getByName("l"))
            myFieldHandler.changeUserFieldContent(
                "State", oUserDataAccess.getByName("st"))
        except Exception:
            traceback.print_exc()

    def killEmptyUserFields(self):
        myFieldHandler = TextFieldHandler(
            self.xMSF, self.xTextDocument)
        myFieldHandler.removeUserFieldByContent()

    def killEmptyFrames(self):
        try:
            if not self.keepLogoFrame:
                xTF = self.getFrameByName(
                    "Company Logo", self.xTextDocument)
                if xTF is not None:
                    xTF.dispose()

            if not self.keepBendMarksFrame:
                xTF = self.getFrameByName(
                    "Bend Marks", self.xTextDocument)
                if xTF is not None:
                    xTF.dispose()

            if not self.keepLetterSignsFrame:
                xTF = self.getFrameByName(
                    "Letter Signs", self.xTextDocument)
                if xTF is not None:
                    xTF.dispose()

            if not self.keepSenderAddressRepeatedFrame:
                xTF = self.getFrameByName(
                    "Sender Address Repeated", self.xTextDocument)
                if xTF is not None:
                    xTF.dispose()

            if not self.keepAddressFrame:
                xTF = self.getFrameByName(
                    "Sender Address", self.xTextDocument)
                if xTF is not None:
                    xTF.dispose()

        except Exception:
            traceback.print_exc()

class BusinessPaperObject(object):

    def __init__(self, xTextDocument, FrameText, Width, Height, XPos, YPos):
        self.xTextDocument = xTextDocument
        self.iWidth = Width
        self.iHeight = Height
        self.iXPos = XPos
        self.iYPos = YPos
        self.xFrame = None
        try:
            self.xFrame = \
                self.xTextDocument.createInstance(
                    "com.sun.star.text.TextFrame")
            self.setFramePosition()
            self.xFrame.AnchorType = AT_PAGE
            self.xFrame.SizeType = FIX

            self.xFrame.TextWrap = THROUGHT
            self.xFrame.Opaque = True
            self.xFrame.BackColor = 15790320

            myBorder = BorderLine()
            myBorder.OuterLineWidth = 0
            self.xFrame.LeftBorder = myBorder
            self.xFrame.RightBorder = myBorder
            self.xFrame.TopBorder = myBorder
            self.xFrame.BottomBorder = myBorder
            self.xFrame.Print = False
            xTextCursor = \
                self.xTextDocument.Text.createTextCursor()
            xTextCursor.gotoEnd(True)
            xText = self.xTextDocument.Text
            xText.insertTextContent(
                xTextCursor, self.xFrame,
                False)

            xFrameText = self.xFrame.Text
            xFrameCursor = xFrameText.createTextCursor()
            xFrameCursor.setPropertyValue("CharWeight", BOLD)
            xFrameCursor.setPropertyValue("CharColor", 16777215)
            xFrameCursor.setPropertyValue("CharFontName", "Albany")
            xFrameCursor.setPropertyValue("CharHeight", 18)

            xFrameText.insertString(xFrameCursor, FrameText, False)
        except Exception:
            traceback.print_exc()

    def setFramePosition(self):
        try:
            self.xFrame.HoriOrient = NONEHORI
            self.xFrame.VertOrient = NONEVERT
            self.xFrame.Height = self.iHeight
            self.xFrame.Width = self.iWidth
            self.xFrame.HoriOrientPosition = self.iXPos
            self.xFrame.VertOrientPosition = self.iYPos
            self.xFrame.HoriOrientRelation = PAGE_FRAME
            self.xFrame.VertOrientRelation = PAGE_FRAME
        except Exception:
            traceback.print_exc()

    def removeFrame(self):
        if self.xFrame is not None:
            try:
                self.xTextDocument.Text.removeTextContent(
                    self.xFrame)
            except UnknownPropertyException:
                pass
            except Exception:
                traceback.print_exc()



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
import traceback
from ..common.Configuration import Configuration
from ..common.Properties import Properties
from ..document.OfficeDocument import OfficeDocument

class WebWizardDialogResources(object):

    RID_WEBWIZARDDIALOG_START = 4000
    RID_COMMON_START = 500
    RID_DB_COMMON_START = 1000
    RID_WEBWIZARDROADMAP_START = 4121

    def __init__(self, xmsf, oWizardResource):
        try:
            #python 3
            self.resbtnDocUp_value = chr(8743)
            self.resbtnDocDown_value = chr(8744)
        except ValueError:
            #python 2
            self.resbtnDocUp_value = unichr(8743)
            self.resbtnDocDown_value = unichr(8744) 
                    
        self.resWebWizardDialog_title = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 1)
        self.reslblIntroduction_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 2)
        self.resbtnDelSession_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 4)
        self.reslbIntroTitle_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 5)
        self.reslblContentTitle_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 6)
        self.reslnDocsInfo_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 8)
        self.reslblDocTitle_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 9)
        self.reslblDocInfo_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 10)
        self.reslblDocAuthor_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 11)
        self.reslblDocExportFormat_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 12)
        self.reslblTitleGeneralPage_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 13)
        self.reslblSiteTitle_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 14)
        self.reslblSiteDesc_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 16)
        self.reslblSiteCreated_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 18)
        self.reslblEmail_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 20)
        self.reslblCopyright_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 21)
        self.reslblSiteUpdated_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 22)
        self.resbtnPreview_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 24)
        self.reslblTitlePublish_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 25)
        self.reslblCreateSite_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 26)
        self.reschkLocalDir_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 27)
        self.resbtnLocalDir_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 28)
        self.reschkFTP_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 29)

        self.resbtnFTP_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 31)
        self.reschkZip_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 32)
        self.resbtnZip_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 33)
        self.reschkSaveSettings_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 34)
        self.reslblSaveSettings_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 35)
        self.reslblLoadSettings_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 36)
        self.reslblSiteContent_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 37)
        self.resbtnAddDoc_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 38)
        self.resbtnRemoveDoc_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 39)
        self.reslblLayoutTitle_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 40)
        self.reslblStyleTitle_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 41)
        self.reslblStyle_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 42)

        self.reslblLayouts_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 48)

        self.reschbDocDesc_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 50)
        self.reschbDocAuthor_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 51)
        self.reschkDocCreated_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 52)
        self.reschkDocChanged_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 53)
        self.reschkDocFilename_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 54)
        self.reschkDocFormat_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 55)
        self.reschkDocFormatIcon_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 56)
        self.reschkDocPages_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 57)
        self.reschkDocSize_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 58)
        self.resFixedLine1_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 59)
        self.reslblLayout2Title_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 60)
        self.reslblDisplay_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 61)
        self.reslblOptimizeFor_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 62)
        self.resoptOptimize640x480_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 64)
        self.resoptOptimize800x600_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 65)
        self.resoptOptimize1024x768_value = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 66)

        self.resStatusDialogTitle = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 70)
        self.resCounter = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 71)
        self.resPublishDir = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 72)
        self.resFTPTargetExistsAsfile = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 73)
        self.resLocalTargetExistsAsfile = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 74)
        self.resZipTargetExists = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 75)
        self.resFTPTargetNotEmpty = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 76)
        self.resLocalTragetNotEmpty = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 77)
        self.resSessionExists = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 78)
        self.resTaskExportDocs = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 79)
        self.resTaskExportPrepare = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 80)
        self.resTaskGenerateCopy = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 81)
        self.resTaskGeneratePrepare = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 82)
        self.resTaskGenerateXsl = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 83)
        self.resTaskPrepare = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 84)
        self.resTaskPublishPrepare = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 86)
        self.resTaskPublishLocal = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 87)
        self.resTaskPublishFTP = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 88)
        self.resTaskPublishZip = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 89)
        self.resTaskFinish = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 90)

        self.resImages = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 94)
        self.resAllFiles = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 95)
        self.resZipFiles = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 96)
        self.resBackgroundsDialog = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 98)
        self.resBackgroundsDialogCaption = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 99)
        self.resIconsDialog = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 100)
        self.resIconsDialogCaption = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 101)
        self.resOther = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 102)
        self.resDeselect = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 103)
        self.resFinishedSuccess = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 104)
        self.resFinishedNoSuccess = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 105)
        self.resErrTOC = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 106)
        self.resErrTOCMedia = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 107)
        self.resErrDocInfo = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 108)
        self.resErrDocExport = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 109)
        self.resErrMkDir = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 110)
        self.resErrSecurity = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 111)
        self.resErrExportIO = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 112)
        self.resErrPublishMedia = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 113)
        self.resErrPublish = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 114)
        self.resErrUnknown = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 115)
        self.resErrDocValidate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 116)
        self.resErrIsDirectory = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 117)
        self.resLoadingSession = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 118)
        self.resErrUnexpected = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 119)
        self.resValidatingDocuments = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 120)
        self.resDefaultArchiveFilename = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 121)
        self.resDelSessionConfirm = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 130)
        self.resPages = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 131)
        self.resSlides = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 132)
        self.resCreatedTemplate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 133)
        self.resUpdatedTemplate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 134)
        self.resSessionName = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 135)
        self.reslblBackground = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 136)
        self.reslblIconset = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 137)
        self.reslblIconSetInfo = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 138)
        self.reslblMetaData = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 139)
        self.resBtnChooseBackground = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 140)
        self.resBtnChooseIconset = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 141)
        self.resSessionNameNone = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 142)
        self.reslblFTPDisabled = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 143)
        self.resBackgroundNone = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 144)
        self.resIconsetNone = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 145)
        self.resFTPTargetCouldNotCreate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 146)
        self.resFTPTargetCreate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 147)
        self.resZipTargetIsDir = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 148)
        self.resLocalTargetCouldNotCreate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 149)
        self.resLocalTargetCreate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 150)
        self.resSizeTemplate = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 151)
        self.resSpecifyNewFileLocation = oWizardResource.getResText(
            WebWizardDialogResources.RID_WEBWIZARDDIALOG_START + 152)
        self.resClose = oWizardResource.getResText(
            WebWizardDialogResources.RID_COMMON_START + 17)
        self.resCancel = oWizardResource.getResText(
            WebWizardDialogResources.RID_COMMON_START + 11)
        self.resOK = oWizardResource.getResText(
            WebWizardDialogResources.RID_COMMON_START + 18)
        self.resHelp = oWizardResource.getResText(
            WebWizardDialogResources.RID_COMMON_START + 15)
            
            
        self.RoadmapLabels = oWizardResource.getResArray(
            WebWizardDialogResources.RID_WEBWIZARDROADMAP_START + 1 , 7)
                        
        try:
            self.prodName = Configuration.getProductName(xmsf)
            self.resGifFiles = Properties.getPropertyValue(
                OfficeDocument.getTypeMediaDescriptor(
                    xmsf, "gif_Graphics_Interchange"), "UIName")
        except Exception as ex:
            traceback.print_exc()



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#

class LetterWizardDialogResources(object):

    RID_LETTERWIZARDDIALOG_START = 3000
    RID_LETTERWIZARDGREETING_START = 3080
    RID_LETTERWIZARDSALUTATION_START = 3090
    RID_LETTERWIZARDROADMAP_START = 3100
    RID_LETTERWIZARDLANGUAGE_START = 3110
    RID_RID_COMMON_START = 500

    def __init__(self, oWizardResource):

        self.resLetterWizardDialog_title = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 1)
        self.resLabel9_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 2)
        self.resoptBusinessLetter_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 3)
        self.resoptPrivOfficialLetter_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 4)
        self.resoptPrivateLetter_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 5)
        self.reschkBusinessPaper_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 6)
        self.reschkPaperCompanyLogo_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 7)
        self.reschkPaperCompanyAddress_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 8)
        self.reschkPaperFooter_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 9)
        self.reschkCompanyReceiver_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 10)
        self.reschkUseLogo_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 11)
        self.reschkUseAddressReceiver_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 12)
        self.reschkUseSigns_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 13)
        self.reschkUseSubject_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 14)
        self.reschkUseSalutation_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 15)
        self.reschkUseBendMarks_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 16)
        self.reschkUseGreeting_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 17)
        self.reschkUseFooter_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 18)
        self.resoptSenderPlaceholder_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 19)
        self.resoptSenderDefine_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 20)
        self.resoptReceiverPlaceholder_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 21)
        self.resoptReceiverDatabase_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 22)
        self.reschkFooterNextPages_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 23)
        self.reschkFooterPageNumbers_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 24)
        self.restxtTemplateName_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 25)
        self.resoptCreateLetter_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 26)
        self.resoptMakeChanges_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 27)
        self.reslblBusinessStyle_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 28)
        self.reslblPrivOfficialStyle_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 29)
        self.reslblPrivateStyle_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 30)
        self.reslblIntroduction_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 31)
        self.reslblLogoHeight_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 32)
        self.reslblLogoWidth_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 33)
        self.reslblLogoX_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 34)
        self.reslblLogoY_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 35)
        self.reslblAddressHeight_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 36)
        self.reslblAddressWidth_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 37)
        self.reslblAddressX_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 38)
        self.reslblAddressY_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 39)
        self.reslblFooterHeight_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 40)
        self.reslblSenderAddress_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 42)
        self.reslblSenderName_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 43)
        self.reslblSenderStreet_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 44)
        self.reslblPostCodeCity_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 45)
        self.reslblReceiverAddress_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 46)
        self.reslblFooter_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 47)
        self.reslblFinalExplanation1_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 48)
        self.reslblFinalExplanation2_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 49)
        self.reslblTemplateName_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 50)
        self.reslblTemplatePath_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 51)
        self.reslblProceed_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 52)
        self.reslblTitle1_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 53)
        self.reslblTitle3_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 54)
        self.reslblTitle2_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 55)
        self.reslblTitle4_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 56)
        self.reslblTitle5_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 57)
        self.reslblTitle6_value = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 58)

        #Create a Dictionary for the constants values.
        self.dictConstants = {
        "#subjectconst#" : oWizardResource.getResText(
            LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 59)}

        #Create a dictionary for localising the business templates
        self.dictBusinessTemplate = {
        "Elegant" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 60),
        "Modern" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 61),
        "Office" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 62)}

        #Create a dictionary for localising the official templates
        self.dictOfficialTemplate = {
        "Elegant" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 60),
        "Modern" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 61),
        "Office" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 62)}

        #Create a dictionary for localising the private templates
        self.dictPrivateTemplate = {
        "Bottle" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 63),
        "Mail" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 64),
        "Marine" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 65),
        "RedLine" : oWizardResource.getResText(
                LetterWizardDialogResources.RID_LETTERWIZARDDIALOG_START + 66)}

        #Common Resources
        self.resOverwriteWarning = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_RID_COMMON_START + 19)
        self.resTemplateDescription = \
            oWizardResource.getResText(
                LetterWizardDialogResources.RID_RID_COMMON_START + 20)

        self.RoadmapLabels = oWizardResource.getResArray(
            LetterWizardDialogResources.RID_LETTERWIZARDROADMAP_START + 1, 6)
        self.SalutationLabels = oWizardResource.getResArray(
            LetterWizardDialogResources.RID_LETTERWIZARDSALUTATION_START + 1, 3)
        self.GreetingLabels = oWizardResource.getResArray(
            LetterWizardDialogResources.RID_LETTERWIZARDGREETING_START + 1, 3)



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
import uno
import traceback
from unohelper import systemPathToFileUrl, absolutize
from ..common.Desktop import Desktop

from com.sun.star.awt import WindowDescriptor
from com.sun.star.awt import Rectangle
from com.sun.star.awt.WindowClass import TOP
from com.sun.star.task import ErrorCodeIOException

#Window Constants
com_sun_star_awt_WindowAttribute_BORDER \
    = uno.getConstantByName( "com.sun.star.awt.WindowAttribute.BORDER" )
com_sun_star_awt_WindowAttribute_SIZEABLE \
    = uno.getConstantByName( "com.sun.star.awt.WindowAttribute.SIZEABLE" )
com_sun_star_awt_WindowAttribute_MOVEABLE \
    = uno.getConstantByName( "com.sun.star.awt.WindowAttribute.MOVEABLE" )
com_sun_star_awt_VclWindowPeerAttribute_CLIPCHILDREN \
    = uno.getConstantByName(
        "com.sun.star.awt.VclWindowPeerAttribute.CLIPCHILDREN" )

class OfficeDocument(object):
    '''Creates a new instance of OfficeDocument '''

    def __init__(self, _xMSF):
        self.xMSF = _xMSF

    @classmethod
    def attachEventCall(self, xComponent, EventName, EventType, EventURL):
        try:
            oEventProperties = list(range(2))
            oEventProperties[0] = uno.createUnoStruct(
                'com.sun.star.beans.PropertyValue')
            oEventProperties[0].Name = "EventType"
            oEventProperties[0].Value = EventType
            # "Service", "StarBasic"
            oEventProperties[1] = uno.createUnoStruct(
                'com.sun.star.beans.PropertyValue')
            oEventProperties[1].Name = "Script" #"URL";
            oEventProperties[1].Value = EventURL
            uno.invoke(xComponent.Events, "replaceByName",
                (EventName, uno.Any("[]com.sun.star.beans.PropertyValue",
                    tuple(oEventProperties))))
        except Exception:
            traceback.print_exc()

    def dispose(self, xMSF, xComponent):
        try:
            if xComponent is not None:
                xFrame = xComponent.CurrentController.Frame
                if xComponent.isModified():
                    xComponent.setModified(False)

                Desktop.dispatchURL(xMSF, ".uno:CloseDoc", xFrame)

        except PropertyVetoException:
            traceback.print_exc()

    '''
    Create a new office document, attached to the given frame.
    @param desktop
    @param frame
    @param sDocumentType e.g. swriter, scalc, ( simpress, scalc : not tested)
    @return the document Component
    (implements XComponent) object ( XTextDocument, or XSpreadsheedDocument )
    '''

    @classmethod
    def createNewDocument(self, frame, sDocumentType, preview, readonly):
        loadValues = list(range(2))
        loadValues[0] = uno.createUnoStruct(
            'com.sun.star.beans.PropertyValue')
        loadValues[0].Name = "ReadOnly"
        if readonly:
            loadValues[0].Value = True
        else:
            loadValues[0].Value = False

        loadValues[1] = uno.createUnoStruct(
            'com.sun.star.beans.PropertyValue')
        loadValues[1].Name = "Preview"
        if preview:
            loadValues[1].Value = True
        else:
            loadValues[1].Value = False
        sURL = "private:factory/" + sDocumentType
        xComponent = None
        try:
            xComponent = frame.loadComponentFromURL(
                sURL, "_self", 0, tuple(loadValues))

        except Exception:
            traceback.print_exc()

        return xComponent

    @classmethod
    def createNewFrame(self, xMSF, listener, FrameName="_blank"):
        xFrame = None
        if FrameName.lower() == "WIZARD_LIVE_PREVIEW".lower():
            xFrame = self.createNewPreviewFrame(xMSF, listener)
        else:
            xF = Desktop.getDesktop(xMSF)
            xFrame = xF.findFrame(FrameName, 0)
            if listener is not None:
                xFF = xF.getFrames()
                xFF.remove(xFrame)
                xF.addTerminateListener(listener)

        return xFrame

    @classmethod
    def createNewPreviewFrame(self, xMSF, listener):
        xToolkit = None
        try:
            xToolkit = xMSF.createInstance("com.sun.star.awt.Toolkit")
        except Exception:
            # TODO Auto-generated catch block
            traceback.print_exc()

        #describe the window and its properties
        aDescriptor = WindowDescriptor()
        aDescriptor.Type = TOP
        aDescriptor.WindowServiceName = "window"
        aDescriptor.ParentIndex = -1
        aDescriptor.Parent = None
        aDescriptor.Bounds = Rectangle(10, 10, 640, 480)

        #Set Window Attributes
        gnDefaultWindowAttributes = \
            com_sun_star_awt_WindowAttribute_BORDER + \
            com_sun_star_awt_WindowAttribute_MOVEABLE + \
            com_sun_star_awt_WindowAttribute_SIZEABLE + \
            com_sun_star_awt_VclWindowPeerAttribute_CLIPCHILDREN

        aDescriptor.WindowAttributes = gnDefaultWindowAttributes
        #create a new blank container window
        xPeer = None
        try:
            xPeer = xToolkit.createWindow(aDescriptor)
        except IllegalArgumentException:
            traceback.print_exc()

        #define some further properties of the frame window
        #if it's needed .-)
        #xPeer->setBackground(...);
        #create new empty frame and set window on it
        xFrame = None
        try:
            xFrame = xMSF.createInstance("com.sun.star.frame.Frame")
        except Exception:
            traceback.print_exc()

        xFrame.initialize(xPeer)
        #from now this frame is useable ...
        #and not part of the desktop tree.
        #You are alone with him .-)
        if listener is not None:
            Desktop.getDesktop(xMSF).addTerminateListener(listener)

        return xFrame

    @classmethod
    def load(self, xInterface, sURL, sFrame, xValues):
        xComponent = None
        try:
            if not sURL.startswith("file://"):
                sURL = systemPathToFileUrl(sURL)
            xComponent = xInterface.loadComponentFromURL(
                sURL, sFrame, 0, tuple(xValues))
        except Exception:
            traceback.print_exc()

        return xComponent

    @classmethod
    def store(self, xMSF, xComponent, StorePath, FilterName):
        try:
            if len(FilterName):
                oStoreProperties = list(range(2))
                oStoreProperties[0] = uno.createUnoStruct(
                    'com.sun.star.beans.PropertyValue')
                oStoreProperties[0].Name = "FilterName"
                oStoreProperties[0].Value = FilterName
                oStoreProperties[1] = uno.createUnoStruct(
                    'com.sun.star.beans.PropertyValue')
                oStoreProperties[1].Name = "InteractionHandler"
                oStoreProperties[1].Value = xMSF.createInstance(
                    "com.sun.star.comp.uui.UUIInteractionHandler")
            else:
                oStoreProperties = list(range(0))      

            StorePath = systemPathToFileUrl(StorePath)
            sPath = StorePath[:(StorePath.rfind("/") + 1)]
            sFile = StorePath[(StorePath.rfind("/") + 1):]
            xComponent.storeToURL(
                absolutize(sPath, sFile), tuple(oStoreProperties))
            return True
        except ErrorCodeIOException:
            #Throw this exception when trying to save a file 
            #which is already opened in Libreoffice
            #TODO: handle it properly
            return True
            pass
        except Exception:
            traceback.print_exc()
            return False

    def close(self, xComponent):
        bState = False
        if xComponent is not None:
            try:
                xComponent.close(True)
                bState = True
            except com.sun.star.util.CloseVetoException:
                print ("could not close doc")
                bState = False

        else:
            xComponent.dispose()
            bState = True

        return bState

    def ArraytoCellRange(self, datalist, oTable, xpos, ypos):
        try:
            rowcount = datalist.length
            if rowcount > 0:
                colcount = datalist[0].length
                if colcount > 0:
                    xNewRange = oTable.getCellRangeByPosition(
                        xpos, ypos, (colcount + xpos) - 1,
                            (rowcount + ypos) - 1)
                    xNewRange.setDataArray(datalist)

        except Exception:
            traceback.print_exc()

    @classmethod
    def getFileMediaDecriptor(self, xmsf, url):
        typeDetect = xmsf.createInstance(
            "com.sun.star.document.TypeDetection")
        mediaDescr = list(range(1))
        mediaDescr[0] = uno.createUnoStruct(
            'com.sun.star.beans.PropertyValue')
        mediaDescr[0].Name = "URL"
        mediaDescr[0].Value = url
        Type = typeDetect.queryTypeByDescriptor(tuple(mediaDescr), True)[0]
        if Type == "":
            return None
        else:
            return typeDetect.getByName(Type)

    @classmethod
    def getTypeMediaDescriptor(self, xmsf, type):
        typeDetect = xmsf.createInstance(
            "com.sun.star.document.TypeDetection")
        return typeDetect.getByName(type)

    def showMessageBox(
        self, xMSF, windowServiceName, windowAttribute, MessageText):

        return SystemDialog.showMessageBox(
            xMSF, windowServiceName, windowAttribute, MessageText)



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
import uno

from .DataAware import DataAware

class SimpleDataAware(DataAware):

    def __init__(self, dataObject, field, control_, controlField_):
        super(SimpleDataAware, self).__init__(dataObject, field)
        self.control = control_
        self.controlField = controlField_

    def setToUI(self, value):
        uno.invoke(self.control, "set" + self.controlField, (value,))

    def getFromUI(self):
        return uno.invoke(self.control, "get" + self.controlField, ())



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .


from .WebWizardConst import *
from ..common.IRenderer import IRenderer


# receives status calls from the status dialog which
# appears when the user clicks "create".
# allocates strings from the resources to
# display the current task status.
# (renders the state to resource strings)
class ProcessStatusRenderer(IRenderer):

    strings = {}

    def __init__(self, res):
        self.strings[TASK_EXPORT_DOCUMENTS] = res.resTaskExportDocs
        self.strings[TASK_EXPORT_PREPARE] = res.resTaskExportPrepare
        self.strings[TASK_GENERATE_COPY] = res.resTaskGenerateCopy
        self.strings[TASK_GENERATE_PREPARE] = res.resTaskGeneratePrepare
        self.strings[TASK_GENERATE_XSL] = res.resTaskGenerateXsl
        self.strings[TASK_PREPARE] = res.resTaskPrepare
        self.strings[LOCAL_PUBLISHER] = res.resTaskPublishLocal
        self.strings[ZIP_PUBLISHER] = res.resTaskPublishZip
        self.strings[FTP_PUBLISHER] = res.resTaskPublishFTP

        self.strings[TASK_PUBLISH_PREPARE] = res.resTaskPublishPrepare
        self.strings[TASK_FINISH] = res.resTaskFinish

    def render(self, object):
        return self.strings[object]




#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
import com.sun.star.io.IOException;
import com.sun.star.lang.XMultiServiceFactory;
import com.sun.star.wizards.common.PropertyNames;
import com.sun.star.wizards.ui.event.Task;
import com.sun.star.wizards.web.data.CGDocument;
import com.sun.star.wizards.web.data.CGSession;

from .ConfiguredExporter import ConfiguredExporter

class ImpressHTMLExporter(ConfiguredExporter):

    SMALL_IMAGE = 512
    MEDIUM_IMAGE = 640
    LARGE_IMAGE = 800

    def export(source, targetDirectory, xmsf, task):

        # here set some filter specific properties.
        # other properties, which are not dependent on
        # user input are set through the exporter
        # configuration.

        session = self.getSession(source)

        self.props["Author"] = source.cp_Author
        self.props["Email"] = session.cp_GeneralInfo.cp_Email
        self.props["HomepageURL"] = self.getHomepageURL(session)
        self.props["UserText"] = self.source.cp_Title

        props[PropertyNames.PROPERTY_WIDTH] = self.getImageWidth(session)

        props["UseButtonSet"] = int(session.cp_Design.cp_IconSet)


        # now export
        return super(ImpressHTMLExporter, self).export(source, targetDirectory, xmsf, task)


    def getHomepageURL(session):
        return "../" + "../index.html" if (exporter.cp_OwnDirectory) else  "index.html"

    def getImageWidth(session):
        size = session.cp_Design.cp_OptimizeDisplaySize
        if (size ==  0):
            return self.SMALL_IMAGE
        elif (size ==  1):
            return self.MEDIUM_IMAGE
        elif (size ==  2):
            return self.LARGE_IMAGE
        return self.MEDIUM_IMAGE

    def getSession(doc):
        return doc.getSettings().cp_DefaultSession



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#

import uno

# a UNO struct later needed to create a document
from com.sun.star.text.ControlCharacter import PARAGRAPH_BREAK
from com.sun.star.text.TextContentAnchorType import AS_CHARACTER
from com.sun.star.awt import Size

from com.sun.star.lang import XMain

def insertTextIntoCell( table, cellName, text, color ):
    tableText = table.getCellByName( cellName )
    cursor = tableText.createTextCursor()
    cursor.setPropertyValue( "CharColor", color )
    tableText.setString( text )


def createTable():
    """creates a new writer document and inserts a table with some data (also known as the SWriter sample)""" 
    ctx = uno.getComponentContext()
    smgr = ctx.ServiceManager
    desktop = smgr.createInstanceWithContext( "com.sun.star.frame.Desktop",ctx)
    
    # open a writer document
    doc = desktop.loadComponentFromURL( "private:factory/swriter","_blank", 0, () )
    
    text = doc.Text
    cursor = text.createTextCursor()
    text.insertString( cursor, "The first line in the newly created text document.\n", 0 )
    text.insertString( cursor, "Now we are in the second line\n" , 0 )
    
    # create a text table
    table = doc.createInstance( "com.sun.star.text.TextTable" )

    # with 4 rows and 4 columns
    table.initialize( 4,4)

    text.insertTextContent( cursor, table, 0 )
    rows = table.Rows

    table.setPropertyValue( "BackTransparent", uno.Bool(0) )
    table.setPropertyValue( "BackColor", 13421823 )
    row = rows.getByIndex(0)
    row.setPropertyValue( "BackTransparent", uno.Bool(0) )
    row.setPropertyValue( "BackColor", 6710932 )

    textColor = 16777215

    insertTextIntoCell( table, "A1", "FirstColumn", textColor )
    insertTextIntoCell( table, "B1", "SecondColumn", textColor )
    insertTextIntoCell( table, "C1", "ThirdColumn", textColor )
    insertTextIntoCell( table, "D1", "SUM", textColor )

    values = ( (22.5,21.5,121.5),
              (5615.3,615.3,-615.3),
              (-2315.7,315.7,415.7) )
    table.getCellByName("A2").setValue(22.5)
    table.getCellByName("B2").setValue(5615.3)
    table.getCellByName("C2").setValue(-2315.7)
    table.getCellByName("D2").setFormula("sum <A2:C2>")

    table.getCellByName("A3").setValue(21.5)
    table.getCellByName("B3").setValue(615.3)
    table.getCellByName("C3").setValue(-315.7)
    table.getCellByName("D3").setFormula("sum <A3:C3>")

    table.getCellByName("A4").setValue(121.5)
    table.getCellByName("B4").setValue(-615.3)
    table.getCellByName("C4").setValue(415.7)
    table.getCellByName("D4").setFormula("sum <A4:C4>")


    cursor.setPropertyValue( "CharColor", 255 )
    cursor.setPropertyValue( "CharShadowed", uno.Bool(1) )

    text.insertControlCharacter( cursor, PARAGRAPH_BREAK, 0 )
    text.insertString( cursor, " This is a colored Text - blue with shadow\n" , 0 )
    text.insertControlCharacter( cursor, PARAGRAPH_BREAK, 0 )

    textFrame = doc.createInstance( "com.sun.star.text.TextFrame" )
    textFrame.setSize( Size(15000,400))
    textFrame.setPropertyValue( "AnchorType" , AS_CHARACTER )

    text.insertTextContent( cursor, textFrame, 0 )

    textInTextFrame = textFrame.getText()
    cursorInTextFrame = textInTextFrame.createTextCursor()
    textInTextFrame.insertString( cursorInTextFrame, "The first line in the newly created text frame.", 0 )
    textInTextFrame.insertString( cursorInTextFrame, "\nWith this second line the height of the rame raises.",0)
    text.insertControlCharacter( cursor, PARAGRAPH_BREAK, 0 )

    cursor.setPropertyValue( "CharColor", 65536 )
    cursor.setPropertyValue( "CharShadowed", uno.Bool(0) )

    text.insertString( cursor, " That's all for now !!" , 0 )

g_exportedScripts = createTable,



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#

from .ImageListDialog import ImageListDialog
from .WWHID import HID_IS
from ..common.FileAccess import FileAccess
from ..common.ListModel import ListModel
from ..ui.ImageList import ImageList

from com.sun.star.awt import Size

'''
@author rpiterman
The dialog class for choosing an icon set.
This class simulates a model, though it does not functions really as one,
since it does not cast events.
It also implements the ImageList.ImageRenderer interface, to handle
its own objects.
'''

class IconsDialog(ImageListDialog, ImageList.IImageRenderer, ListModel):

    def __init__(self, xmsf, set_, resources):
        super(IconsDialog, self).__init__(xmsf, HID_IS,
            (resources.resIconsDialog,
                resources.resIconsDialogCaption,
                resources.resOK,
                resources.resCancel,
                resources.resHelp,
                resources.resDeselect,
                resources.resOther,
                resources.resCounter))
        self.htmlexpDirectory = FileAccess.getOfficePath2(
            xmsf, "Gallery", "share", "")
        self.icons = \
            ["firs", "prev", "next", "last", "nav", "text", "up", "down"]
        self.set = set_
        self.objects = range(self.set.getSize() * len(self.icons))

        self.il.listModel = self
        self.il.renderer = self
        self.il.rows = 4
        self.il.cols = 8
        self.il.ImageSize = Size (20, 20)
        self.il.showButtons = False
        self.il.rowSelect = True
        self.il.scaleImages = False
        self.showDeselectButton = True
        self.showOtherButton = False
        self.build()

    def getIconset(self):
        if self.getSelected() is None:
            return None
        else:
            selected = self.getSelected()
            value = int(selected / len(self.icons))
            return "iconset" + str(value)
            #return self.set.getKey(value)

    def setIconset(self, iconset):
        icon = self.set.getIndexOf(self.set.getElement(iconset)) * len(self.icons)
        aux = None
        if icon >=0:
            aux = self.objects[icon]
        self.setSelected(aux)

    def addListDataListener(self, listener):
        pass

    def removeListDataListener(self, listener):
        pass

    def getSize(self):
        return self.set.getSize() * len(self.icons)

    def getElementAt(self, arg0):
        return self.objects[arg0]

    def getImageUrls(self, listItem):
        i = listItem
        iset = self.getIconsetNum(i)
        icon = self.getIconNum(i)
        sRetUrls = list(range(2))
        sRetUrls[0] = self.htmlexpDirectory + "/htmlexpo/" \
            + self.getIconsetPref(iset) + self.icons[icon] + self.getIconsetPostfix(iset)
        sRetUrls[1] = sRetUrls[0]
        return sRetUrls

    def render(self, object):
        if object is None:
            return ""

        i = object
        iset = self.getIconsetNum(i)
        return self.getIconset1(iset).cp_Name

    def getIconsetNum(self, i):
        return int(i / len(self.icons))

    def getIconNum(self, i):
        return i % len(self.icons)

    def getIconsetPref(self, iconset):
        return self.getIconset1(iconset).cp_FNPrefix

    def getIconsetPostfix(self, iconset):
        return self.getIconset1(iconset).cp_FNPostfix

    def getIconset1(self, i):
        return self.set.getElementAt(i)



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .

from com.sun.star.awt.VclWindowPeerAttribute import OK, DEF_OK, OK_CANCEL, DEF_CANCEL
from com.sun.star.awt.VclWindowPeerAttribute import YES_NO, DEF_NO

class ErrorHandler:

    MESSAGE_INFO = "infobox"
    MESSAGE_QUESTION = "querybox"
    MESSAGE_ERROR = "errorbox"
    MESSAGE_WARNING = "warningbox"
    BUTTONS_OK = OK
    BUTTONS_OK_CANCEL = OK_CANCEL
    BUTTONS_YES_NO = YES_NO
    RESULT_CANCEL = 0
    RESULT_OK = 1
    RESULT_YES = 2
    DEF_OK = DEF_OK
    DEF_NO = DEF_NO
    DEF_CANCEL = DEF_CANCEL

    #Error type for fatal errors which should abort application
    # execution. Should actually never be used :-)
    ERROR_FATAL = 0
    # An Error type for errors which should stop the current process.
    ERROR_PROCESS_FATAL = 1
    # An Error type for errors to which the user can choose, whether
    # to continue or to abort the current process.
    # default is abort.
    ERROR_NORMAL_ABORT = 2
    # An Error type for errors to which the user can choose, whether
    # to continue or to abort the current process.
    # default is continue.
    ERROR_NORMAL_IGNORE = 3
    # An error type for warnings which requires user interaction.
    # (a question :-) )
    # Default is abort (cancel).
    ERROR_QUESTION_CANCEL = 4
    # An error type for warnings which requires user interaction
    # (a question :-) )
    # Default is to continue (ok).
    ERROR_QUESTION_OK = 5
    # An error type for warnings which requires user interaction.
    # (a question :-) )
    # Default is abort (No).
    ERROR_QUESTION_NO = 6
    # An error type for warnings which requires user interaction
    # (a question :-) )
    # Default is to continue (Yes).
    ERROR_QUESTION_YES = 7
    # An error type which is just a warning...
    ERROR_WARNING = 8
    # An error type which just tells the user something
    # ( like "you look tired! you should take a bath! and so on)
    ERROR_MESSAGE = 9

    # @param ex the exception that accured
    # @param arg an object as help for recognizing the exception
    # @param ix an integer which helps for detailed recognizing of the exception
    # @param errorType one of the int constants defined by this Interface
    # @return true if the execution should continue, false if it should stop.
    def error(self, ex, arg, ix, errorType):
        pass




#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
from ..abc import abstractmethod

class Exporter:

    # This method exports a document with a specified filter.<br/>
    # The method is responsible for exporting the given source document
    # to the given target directory.
    # The exporter *must* also set the given CGDocument sizeBytes field to the
    # size of the converted document, *if* the target document is
    # of a binary format.
    # always use source.urlFilename as destination filename.
    # @param source is a CGDocument object.
    # @param targetDirectory contains the URL of a directory to which the file should be exported to.
    # @param xmsf this is a basic multiServiceFactory.
    # @param task - a task monitoring object. This should advance
    # (call task.advance(true) ) 3 times, while exporting.
    @abstractmethod
    def export(self, source, targetDirectory, xmsf, task):
        pass

    @abstractmethod
    def init(self, exporter):
        pass



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#
LSTLOADSETTINGS_ITEM_CHANGED = "sessionSelected" # "lstLoadSettingsItemChanged"
LSTLOADSETTINGS_ITEM_CHANGED = "sessionSelected" # "lstLoadSettingsItemChanged"
BTNLOADSESSION_ACTION_PERFORMED = "loadSession" # "btnLoadSessionActionPerformed"
BTNDELSESSION_ACTION_PERFORMED = "delSession" # "btnDelSessionActionPerformed"
BTNADDDOC_ACTION_PERFORMED = "addDocument" # "btnAddDocActionPerformed"
BTNREMOVEDOC_ACTION_PERFORMED = "removeDocument" # "btnRemoveDocActionPerformed"
BTNDOCUP_ACTION_PERFORMED = "docUp" # "btnDocUpActionPerformed"
BTNDOCDOWN_ACTION_PERFORMED = "docDown" # "btnDocDownActionPerformed"
LSTSTYLES_ITEM_CHANGED = "refreshStylePreview" # "lstStylesItemChanged"
BTNBACKGROUNDS_ACTION_PERFORMED = "chooseBackground" # "btnBackgroundsActionPerformed"
BTNICONSETS_ACTION_PERFORMED = "chooseIconset" # "btnIconSetsActionPerformed"
BTNFAVICON_ACTION_PERFORMED = "chooseFavIcon" # "btnFavIconActionPerformed"
BTNPREVIEW_ACTION_PERFORMED = "documentPreview" # "btnPreviewActionPerformed"
BTNFTP_ACTION_PERFORMED = "setFTPPublish" # "btnFTPActionPerformed"
CHKLOCALDIR_ITEM_CHANGED = "chkLocalDirItemChanged" # "chkLocalDirItemChanged"
CHKZIP_ITEM_CHANGED = "chkZipItemChanged"
CHKSAVESETTINGS_ITEM_CHANGED = "checkPublish" # "chkSaveSettingsItemChanged"
TXTSAVESETTINGS_TEXT_CHANGED = "checkPublish" # "txtSaveSettingsTextChanged"
BTNLOCALDIR_ACTION_PERFORMED = "setPublishLocalDir" # "btnLocalDirActionPerformed"
BTNZIP_ACTION_PERFORMED = "setZipFilename" # "btnZipActionPerformed"
CONFIG_PATH = "/org.openoffice.Office.WebWizard/WebWizard"
CONFIG_READ_PARAM = "cp_"
TASK = "WWIZ"
TASK_PREPARE = "t-prep"
LOCAL_PUBLISHER = "local"
FTP_PUBLISHER = "ftp"
ZIP_PUBLISHER = "zip"
TASK_EXPORT = "t_exp"
TASK_EXPORT_PREPARE = "t_exp_prep"
TASK_EXPORT_DOCUMENTS = "t_exp_docs"
TASK_GENERATE_PREPARE = "t_gen_prep"
TASK_GENERATE_XSL = "t_gen_x"
TASK_GENERATE_COPY = "t_gen_cp"
TASK_PUBLISH_PREPARE = "t_pub_prep"
TASK_FINISH = "t_fin"

'''
when the user adds more than this number
of documents to the list, a status dialog opens.
'''
MIN_ADD_FILES_FOR_DIALOG = 2



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .

class FTPDialogResources(object):

    RID_FTPDIALOG_START = 4200
    RID_COMMON_START = 500

    def __init__(self, oWizardResource):
        super(FTPDialogResources, self).__init__(xmsf, self.MODULE_NAME)

        self.resFTPDialog_title = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 0)
        self.reslblUsername_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 1)
        self.reslblPassword_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 2)
        self.resbtnConnect_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 3)
        self.resln1_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 4)
        self.reslblFTPAddress_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 5)
        self.resln2_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 6)
        self.resln3_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 7)
        self.resbtnDir_value = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 8)
        self.resFTPDisconnected = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 9)
        self.resFTPConnected = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 10)
        self.resFTPUserPwdWrong = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 11)
        self.resFTPServerNotFound = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 12)
        self.resFTPRights = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 13)
        self.resFTPHostUnreachable = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 14)
        self.resFTPUnknownError = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 15)
        self.resFTPDirectory = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 16)
        self.resIllegalFolder = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 17)
        self.resConnecting = oWizardResource.getResText(
            self.RID_FTPDIALOG_START + 18)

        self.resbtnCancel_value = oWizardResource.getResText(
            self.RID_COMMON_START + 11)
        self.resbtnOK_value = oWizardResource.getResText(
            self.RID_COMMON_START + 18)
        self.resbtnHelp_value = oWizardResource.getResText(
            self.RID_COMMON_START + 15)

        self.restxtDir_value = "/"



#
# This file is part of the LibreOffice project.
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This file incorporates work covered by the following license notice:
#
#   Licensed to the Apache Software Foundation (ASF) under one or more
#   contributor license agreements. See the NOTICE file distributed
#   with this work for additional information regarding copyright
#   ownership. The ASF licenses this file to you under the Apache
#   License, Version 2.0 (the "License"); you may not use this file
#   except in compliance with the License. You may obtain a copy of
#   the License at http://www.apache.org/licenses/LICENSE-2.0 .
#

#
# Translated to python from "Bootstrap.java" by Kim Kulak
#

import os
import random
from sys import platform
from time import sleep

import uno
from com.sun.star.connection import NoConnectException
from com.sun.star.uno import Exception as UnoException


class BootstrapException(UnoException):
    pass

def bootstrap():
    """Bootstrap OOo and PyUNO Runtime.
    The soffice process is started opening a named pipe of random name, then the local context is used
	to access the pipe. This function directly returns the remote component context, from whereon you can
	get the ServiceManager by calling getServiceManager() on the returned object.
	"""
    try:
       # soffice script used on *ix, Mac; soffice.exe used on Win
        if "UNO_PATH" in os.environ:
            sOffice = os.environ["UNO_PATH"]
        else:
            sOffice = "" # lets hope for the best
        sOffice = os.path.join(sOffice, "soffice")
        if platform.startswith("win"):
            sOffice += ".exe"

        # Generate a random pipe name.
        random.seed()
        sPipeName = "uno" + str(random.random())[2:]

        # Start the office process, don't check for exit status since an exception is caught anyway if the office terminates unexpectedly.
        cmdArray = (sOffice, "--nologo", "--nodefault", "".join(["--accept=pipe,name=", sPipeName, ";urp;"]))
        os.spawnv(os.P_NOWAIT, sOffice, cmdArray)

        # ---------

        xLocalContext = uno.getComponentContext()
        resolver = xLocalContext.ServiceManager.createInstanceWithContext(
            "com.sun.star.bridge.UnoUrlResolver", xLocalContext)
        sConnect = "".join(["uno:pipe,name=", sPipeName, ";urp;StarOffice.ComponentContext"])

        # Wait until an office is started, but loop only nLoop times (can we do this better???)
        nLoop = 20
        while True:
            try:
                xContext = resolver.resolve(sConnect)
                break
            except NoConnectException:
                nLoop -= 1
                if nLoop <= 0:
                    raise BootstrapException("Cannot connect to soffice server.", None)
                sleep(0.5)  # Sleep 1/2 second.

    except BootstrapException:
        raise
    except Exception as e:  # Any other exception
        raise BootstrapException("Caught exception " + str(e), None)

    return xContext
